@@ -935,6 +935,12 @@ public final class Constants {
      */
     public static final String LOCALE_LANGUAGE = "language";
 
+    /**
+     * temporary parameter prefix
+     */
+    public static final String START_UP_PARAMS_PREFIX = "startup-";
+    public static final String GLOBAL_PARAMS_PREFIX = "global-";
+
     /**
      * driver
      */
@@ -1092,4 +1098,9 @@ public final class Constants {
     public static final int DRY_RUN_FLAG_YES = 1;
 
     public static final String CACHE_KEY_VALUE_ALL = "'all'";
+
+    /**
+     * tenant
+     */
+    public static final int TENANT_FULL_NAME_MAX_LENGTH = 30;
 }
