@@ -19,6 +19,7 @@ package org.apache.dolphinscheduler.common.utils.placeholder;
 
 import org.apache.dolphinscheduler.common.Constants;
 import org.apache.dolphinscheduler.common.enums.CommandType;
+import org.apache.dolphinscheduler.spi.utils.DateUtils;
 
 import java.util.Date;
 import java.util.HashMap;
@@ -46,7 +47,7 @@ public class BusinessTimeUtils {
      * @return business time
      */
     public static Map<String, String> getBusinessTime(CommandType commandType, Date runTime) {
-        Date businessDate = runTime;
+        Date businessDate;
         Map<String, String> result = new HashMap<>();
         switch (commandType) {
             case COMPLEMENT_DATA:
