@@ -16,3 +16,13 @@
 # under the License.
 
 """Init pydolphinscheduler.core package."""
+
+from pydolphinscheduler.core.database import Database
+from pydolphinscheduler.core.process_definition import ProcessDefinition
+from pydolphinscheduler.core.task import Task
+
+__all__ = [
+    "ProcessDefinition",
+    "Task",
+    "Database",
+]
