@@ -29,6 +29,7 @@ import org.apache.dolphinscheduler.common.enums.StateEvent;
 import org.apache.dolphinscheduler.common.enums.StateEventType;
 import org.apache.dolphinscheduler.common.model.Server;
 import org.apache.dolphinscheduler.common.thread.ThreadUtils;
+import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.NetUtils;
 import org.apache.dolphinscheduler.dao.entity.ProcessInstance;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
@@ -253,12 +254,12 @@ public class MasterRegistryClient {
     }
 
     /**
-     * task needs failover if task start before worker starts
+     * task needs failover if task start before server starts
      *
      * @param taskInstance task instance
      * @return true if task instance need fail over
      */
-    private boolean checkTaskInstanceNeedFailover(List<Server> workerServers, TaskInstance taskInstance) {
+    private boolean checkTaskInstanceNeedFailover(List<Server> servers, TaskInstance taskInstance) {
 
         // first submit: host is null
         // dispatch succeed: host is not null &&  submit_time is null
@@ -274,8 +275,8 @@ public class MasterRegistryClient {
         if (taskInstance.getSubmitTime() == null) {
             return false;
         }
-        //if task start after worker starts, there is no need to failover the task.
-        if (checkTaskAfterWorkerStart(workerServers, taskInstance)) {
+        //if task start after server starts, there is no need to failover the task.
+        if (checkTaskAfterServerStart(servers, taskInstance)) {
             taskNeedFailover = false;
         }
 
@@ -307,21 +308,24 @@ public class MasterRegistryClient {
     }
 
     /**
-     * check task start after the worker server starts.
+     * check task start after the server starts.
      *
      * @param taskInstance task instance
-     * @return true if task instance start time after worker server start date
+     * @return true if task instance start time after server start date
      */
-    private boolean checkTaskAfterWorkerStart(List<Server> workerServers, TaskInstance taskInstance) {
+    private boolean checkTaskAfterServerStart(List<Server> servers, TaskInstance taskInstance) {
         if (StringUtils.isEmpty(taskInstance.getHost())) {
             return false;
         }
 
-        Date taskTime = taskInstance.getStartTime() == null ? taskInstance.getSubmitTime() : taskInstance.getStartTime();
-
-        Date workerServerStartDate = getServerStartupTime(workerServers, taskInstance.getHost());
-        if (workerServerStartDate != null) {
-            return taskTime.after(workerServerStartDate);
+        Date taskSubmitTime = taskInstance.getSubmitTime();
+        Date serverStartTime = getServerStartupTime(servers, taskInstance.getHost());
+        if (taskSubmitTime != null && serverStartTime != null && taskSubmitTime.after(serverStartTime)) {
+            logger.info(
+                    "The taskInstance's submitTime: {} is after the need failover server's start time: {}, the taskInstance is newly submit, it doesn't need to failover",
+                    DateUtils.dateToString(taskSubmitTime),
+                    DateUtils.dateToString(serverStartTime));
+            return true;
         }
         return false;
     }
@@ -417,7 +421,10 @@ public class MasterRegistryClient {
         }
 
         Date serverStartupTime = getServerStartupTime(NodeType.MASTER, masterHost);
-        List<Server> workerServers = registryClient.getServerList(NodeType.WORKER);
+
+        // servers need to contains master hosts and worker hosts, otherwise the logic task will failover fail.
+        List<Server> servers = registryClient.getServerList(NodeType.WORKER);
+        servers.addAll(registryClient.getServerList(NodeType.MASTER));
 
         long startTime = System.currentTimeMillis();
         List<ProcessInstance> needFailoverProcessInstanceList = processService.queryNeedFailoverProcessInstances(masterHost);
@@ -436,7 +443,7 @@ public class MasterRegistryClient {
                 if (taskInstance.getState().typeIsFinished()) {
                     continue;
                 }
-                if (!checkTaskInstanceNeedFailover(workerServers, taskInstance)) {
+                if (!checkTaskInstanceNeedFailover(servers, taskInstance)) {
                     continue;
                 }
                 logger.info("failover task instance id: {}, process instance id: {}", taskInstance.getId(), taskInstance.getProcessInstanceId());
@@ -480,6 +487,8 @@ public class MasterRegistryClient {
                 .buildTaskInstanceRelatedInfo(taskInstance)
                 .buildProcessInstanceRelatedInfo(processInstance)
                 .create();
+        taskExecutionContext.setProcessDefineCode(processInstance.getProcessDefinitionCode());
+        taskExecutionContext.setProcessDefineVersion(processInstance.getProcessDefinitionVersion());
 
         if (masterConfig.getMasterKillYarnJobWhenHandleFailOver()
             && !(taskInstance.isSubProcess()
