@@ -20,8 +20,11 @@ package org.apache.dolphinscheduler.server.master.runner.task;
 /**
  * task action
  */
-public enum  TaskAction {
+public enum TaskAction {
     PAUSE,
     STOP,
-    TIMEOUT
+    TIMEOUT,
+    SUBMIT,
+    RUN,
+    RESUBMIT
 }
