@@ -71,4 +71,12 @@ public class TaskExecutionContextCacheManager {
     public static Collection<TaskRequest> getAllTaskRequestList() {
         return taskRequestContextCache.values();
     }
+
+    public static boolean statusIsStop(Integer taskInstanceId) {
+        TaskRequest taskRequest = taskRequestContextCache.get(taskInstanceId);
+        if (taskRequest == null || taskRequest.getCurrentExecutionStatus() == null) {
+            return false;
+        }
+        return taskRequest.getCurrentExecutionStatus().typeIsStop();
+    }
 }
