@@ -197,6 +197,7 @@ export default {
   'Zk registration directory': 'Zk registration directory',
   cpuUsage: 'cpuUsage',
   memoryUsage: 'memoryUsage',
+  diskAvailable: 'diskAvailable',
   'Last heartbeat time': 'Last heartbeat time',
   'Edit Tenant': 'Edit Tenant',
   'OS Tenant Code': 'OS Tenant Code',
@@ -238,6 +239,7 @@ export default {
   'Instance parameter exception': 'Instance parameter exception',
   'Group Type': 'Group Type',
   'Alarm plugin instance': 'Alarm plugin instance',
+  'Please enter alarm plugin instance name': 'Please enter alarm plugin instance name',
   'Select Alarm plugin instance': 'Please select an Alarm plugin instance',
   Remarks: 'Remarks',
   SMS: 'SMS',
@@ -606,6 +608,7 @@ export default {
   'Please enter Export Dir(required)': 'Please enter Export Dir(required)',
   'Please enter Hive Database(required)': 'Please enter Hive Databasec(required)',
   'Please enter Hive Table(required)': 'Please enter Hive Table(required)',
+  'Please enter hive target dir': 'Please enter hive target dir',
   'Please enter Hive Partition Keys': 'Please enter Hive Partition Key',
   'Please enter Hive Partition Values': 'Please enter Partition Value',
   'Please enter Replace Delimiter': 'Please enter Replace Delimiter',
@@ -724,6 +727,11 @@ export default {
   WebHook: 'WebHook',
   webHook: 'WebHook',
   Keyword: 'Keyword',
+  Secret: 'Secret',
+  MsgType: 'MsgType',
+  AtMobiles: '@Mobiles',
+  AtUserIds: '@UserIds',
+  IsAtAll: '@All',
   Proxy: 'Proxy',
   receivers: 'Receivers',
   receiverCcs: 'ReceiverCcs',
