@@ -196,6 +196,7 @@ export default {
   'Zk registration directory': 'zk注册目录',
   cpuUsage: 'cpuUsage',
   memoryUsage: 'memoryUsage',
+  diskAvailable: 'diskAvailable',
   'Last heartbeat time': '最后心跳时间',
   'Edit Tenant': '编辑租户',
   'OS Tenant Code': '操作系统租户',
@@ -237,6 +238,7 @@ export default {
   'Instance parameter exception': '实例参数异常',
   'Group Type': '组类型',
   'Alarm plugin instance': '告警插件实例',
+  'Please enter alarm plugin instance name': '请输入告警实例名称',
   'Select Alarm plugin instance': '请选择告警插件实例',
   Remarks: '备注',
   SMS: '短信',
@@ -605,6 +607,7 @@ export default {
   'Please enter Export Dir(required)': '请输入数据源路径(必填)',
   'Please enter Hive Database(required)': '请输入Hive数据库(必填)',
   'Please enter Hive Table(required)': '请输入Hive表名(必填)',
+  'Please enter hive target dir': '请输入Hive临时目录',
   'Please enter Hive Partition Keys': '请输入分区键',
   'Please enter Hive Partition Values': '请输入分区值',
   'Please enter Replace Delimiter': '请输入替换分隔符',
@@ -722,7 +725,12 @@ export default {
   IsEnableProxy: '启用代理',
   WebHook: 'Web钩子',
   webHook: 'Web钩子',
-  Keyword: '密钥',
+  Keyword: '关键词',
+  Secret: '密钥',
+  MsgType: '消息类型',
+  AtMobiles: '@手机号',
+  AtUserIds: '@用户ID',
+  IsAtAll: '@所有人',
   Proxy: '代理',
   receivers: '收件人',
   receiverCcs: '抄送人',
